Equal

Trait Equal 

pub trait Equal<Rhs = Self>
where Rhs: ?Sized,
{ type Output; // Required methods fn is_equal(&self, other: &Rhs) -> Self::Output; fn is_not_equal(&self, other: &Rhs) -> Self::Output; }
Trait for equality comparisons.

Required Associated Types

Required Methods

fn is_equal(&self, other: &Rhs) -> Self::Output

Returns true if self and other are equal.

fn is_not_equal(&self, other: &Rhs) -> Self::Output

Returns true if self and other are not equal.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<E> Equal for Scalar<E>
where E: Environment,

Source

fn is_equal(&self, other: &Scalar<E>) -> <Scalar<E> as Equal>::Output

Returns true if self and other are equal.

Source

fn is_not_equal(&self, other: &Scalar<E>) -> <Scalar<E> as Equal>::Output

Returns true if self and other are not equal.

Source

type Output = Boolean<E>

Implementors